@@ -1,4 +1,4 @@
-/* $Id: ttl_calc.h,v 1.1 2002/08/08 11:41:42 fygrave Exp $ */
+/* $Id: ttl_calc.h,v 1.3 2003/08/05 03:35:12 mederchik Exp $ */
 /*
 ** Copyright (C) 2001, 2002 Meder Kydyraliev
 **
@@ -10,7 +10,6 @@
 ** the Free Software Foundation; either version 2 of the License, or
 ** (at your option) any later version.
 **
-** All material for nonprofit, educational use only.
 **
 ** This program is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -49,7 +48,7 @@ class TTL_Mod: public Xprobe_Module {
 	int getrandom(int limit);
     public:
 		/* constructor */
-        TTL_Mod(void) : Xprobe_Module(XPROBE_MODULE_ALIVETEST, "TTL distance") { return; }
+        TTL_Mod(void) : Xprobe_Module(XPROBE_MODULE_ALIVETEST, "infogather:ttl_calc", "TCP and UDP based TTL distance calculation") { return; }
 		/* destructor */
         ~TTL_Mod(void) { return; }
         int init(void);
